@@ -1,6 +1,5 @@
 import cheesyutils
 import copy
-import datetime
 from inspect import Parameter
 import discord
 import re
@@ -10,7 +9,8 @@ from io import StringIO
 from textwrap import indent
 from traceback import format_exc
 from typing import Callable, List, Optional, Union
-from ..utils import get_base_embed, paginate
+from ..utils import paginate
+from ..embed import Embed
 
 
 class _ConversionFailed(commands.BadArgument):
@@ -48,7 +48,7 @@ class _CogConverter(commands.Converter):
         """
 
         cog = ctx.bot.get_cog(argument)
-        if cog is None:
+        if not cog:
             raise _ConversionFailed(argument, f"No cog named {argument!r} found")
         return cog
 
@@ -219,7 +219,7 @@ class Meta(commands.Cog):
 
         prefix = self.bot.database.execute("SELECT prefix FROM prefixes WHERE server_id = ?", parameters=(ctx.guild.id,))
         
-        embed = get_base_embed(title="Bot Prefix", author=ctx.guild)
+        embed = Embed(title="Bot Prefix", author=ctx.guild)
         embed.add_field(
             name="Prefix",
             value=prefix
@@ -361,7 +361,7 @@ class Meta(commands.Cog):
         Display's bot information
         """
 
-        embed = get_base_embed(
+        embed = Embed(
             title="Bot Stats",
             author=self.bot
         )
@@ -439,7 +439,7 @@ class Meta(commands.Cog):
         Returns info about a given cog
         """
 
-        embed = get_base_embed(
+        embed = Embed(
             title=f"Cog Info - {cog.qualified_name}",
             description=cog.description if cog.description != "" else "(No Description Provided)",
             color=self.bot.color,
@@ -472,8 +472,8 @@ class Meta(commands.Cog):
         Loads a particular cog
         """
 
-        await self._execute_extension_actions(ctx, cog, self.bot.load_extension)
-        await self.bot.send_success_embed(ctx, f"Cog `{cog}` was loaded!")
+        if await self._execute_extension_actions(ctx, cog, self.bot.load_extension):
+            await self.bot.send_success_embed(ctx, f"Cog `{cog}` was loaded!")
     
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True, embed_links=True)
@@ -483,15 +483,15 @@ class Meta(commands.Cog):
         Unloads a particular cog
         """
 
-        await self._execute_extension_actions(ctx, cog, self.bot.unload_extension)
-        await self.bot.send_success_embed(ctx, f"Cog `{cog}` was unloaded!")
+        if await self._execute_extension_actions(ctx, cog, self.bot.unload_extension):
+            await self.bot.send_success_embed(ctx, f"Cog `{cog}` was unloaded!")
     
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True)
     @_cog_group.command(name="reload")
     async def _cog_reload_command(self, ctx: commands.Context, cog: str):
-        await self._execute_extension_actions(ctx, cog, self.bot.unload_extension, self.bot.load_extension)
-        await self.bot.send_success_embed(ctx, f"Cog `{cog}` was reloaded!")
+        if await self._execute_extension_actions(ctx, cog, self.bot.unload_extension, self.bot.load_extension):
+            await self.bot.send_success_embed(ctx, f"Cog `{cog}` was reloaded!")
 
     async def _execute_extension_actions(self, ctx: commands.Context, cog: str, *funcs: List[Callable[[str], None]]):
         """Executes a list of extension actions
@@ -511,6 +511,7 @@ class Meta(commands.Cog):
         try:
             for func in funcs:
                 func(cog)
+            return True
         except commands.ExtensionNotFound as e:
             await self.bot.send_fail_embed(ctx, f"Cog `{e.name}` was not found")
         except commands.ExtensionAlreadyLoaded as e:
