@@ -18,7 +18,7 @@ class Embed(discord.Embed):
         if footer:
             self.set_footer_from_entity(footer)
         if thumbnail:
-            self.set_image(url=thumbnail)
+            self.set_thumbnail(url=thumbnail)
         if image:
             self.set_image(url=image)
 
@@ -77,8 +77,8 @@ class Embed(discord.Embed):
         else:
             raise ValueError(f"Expected a discord.User, discord.Member, or discord.Guild but received {entity.__class__.__name__} instead")
 
-    def set_footer(self, *, text: str=discord.embeds._EmptyEmbed, icon_url: str=discord.embeds._EmptyEmbed) -> "Embed":
-        if text is not discord.embeds._EmptyEmbed:
+    def set_footer(self, *, text: str=discord.embeds.EmptyEmbed, icon_url: str=discord.embeds.EmptyEmbed) -> "Embed":
+        if text is not discord.embeds.EmptyEmbed:
             if len(text) > MAX_EMBED_FOOTER_TEXT_LENGTH:
                 raise ValueError(f"Embed field text cannot exceed {MAX_EMBED_FOOTER_TEXT_LENGTH} in length")
         return super().set_footer(text=text, icon_url=icon_url)
@@ -106,7 +106,7 @@ class Embed(discord.Embed):
         elif isinstance(url, discord.Guild):
             url = url.icon_url
 
-        return super().set_image(url)
+        return super().set_image(url=url)
     
     def set_thumbnail(self, *, url) -> "Embed":
         """Sets the thumbnail image for this particular embed.
@@ -126,9 +126,14 @@ class Embed(discord.Embed):
         The class instance.
         """
 
-        return super().set_thumbnail(url)
+        if isinstance(url, (discord.User, discord.Member)):
+            url = url.avatar_url
+        elif isinstance(url, discord.Guild):
+            url = url.icon_url
 
-    def set_author(self, *, name, url=discord.embeds._EmptyEmbed, icon_url=discord.embeds._EmptyEmbed) -> "Embed":
+        return super().set_thumbnail(url=url)
+
+    def set_author(self, *, name, url=discord.embeds.EmptyEmbed, icon_url=discord.embeds.EmptyEmbed) -> "Embed":
         if len(name) > MAX_EMBED_AUTHOR_NAME_LENGTH:
             raise ValueError(f"Embed author name cannot exceed {MAX_EMBED_AUTHOR_NAME_LENGTH} characters in length")
     
